# <img src="/logo.png" height="32" width="32"/> Fireplace 2.0 [![codecov.io](https://codecov.io/github/PotatoHD404/fireplace2/coverage.svg?branch=master)](https://codecov.io/github/PotatoHD404/fireplace2) [![PyPI version](https://badge.fury.io/py/fireplace2.svg)](https://badge.fury.io/py/fireplace2)
## *A Hearthstone simulator and implementation, written in Python.*

## Requirements

* Python 3.8+

## Installation

* clone this repo and `pip install .`
* `pip install fireplace2`

## Documentation

The [Fireplace Wiki](https://github.com/jleclanche/fireplace/wiki) is the best source of documentation, along with the
actual code.

## Community

Fireplace is a [HearthSim](http://hearthsim.info/) project. Join the community: <https://hearthsim.info/join/>

## License

[![AGPLv3](https://www.gnu.org/graphics/agplv3-88x31.png)](http://choosealicense.com/licenses/agpl-3.0/)

Fireplace is licensed under the terms of the
[Affero GPLv3](https://www.gnu.org/licenses/agpl-3.0.en.html) or any later version.
